# Optimiser ses dépenses

Il existe plusieurs moyens d'optimiser ses dépenses en vacances ou en voyage.

Premièrement, nous voulons épargner sur les transports. Est-ce que nous nous déplaçons en voiture ou en transports publics ? Dans le premier cas, considérons le coût de l'essence et du stationnement, et si nous allons dans une grande ville comme Montréal, prévoir un budget pour une contravention (ils sont impitoyables).

Si nous recourons au transport public, il faut examiner s'il y a des promos sur les billets, si nous sommes prêts à faire des transferts, et les horaires.

Ensuite, pensons à l'hébergement : Hôtel, AirBnB ou chez des amis ? Tenons compte du coût de la nuitée, des services offerts ainsi que de la proximité avec les attractions que nous souhaitons visiter.

Bref, tout ça peut rapidement devenir un casse-tête.

C'est à ce moment-là que l'analyse de données peut nous être utile.

## Exemple : Choisir le moyen de transport le moins cher

Nous souhaitons savoir, selon le kilométrage à parcourir, s'il est mieux de se déplacer à pied, en transport en commun ou en voiture.

Prenons la mise en situation suivante pour faire notre analyse :

- À vélo, le coût d'utilisation est nul
- En transport en commun, le coût du billet est fixé à 3 $
- En voiture, le coût d'utilisation est 10\$ /heure et le stationnement est 8\$

Le temps est calculé comme suit :

- En voiture, notre vitesse est de 50 km/h
- En transport public, elle est de 20 km/h et nous devons attendre en moyenne 6 minutes
- À vélo, nous nous déplaçons à 10 km/h

De plus, nous sommes prêts à dépenser 10 $ pour sauver une heure de déplacement. C'est notre coût d'option.

### Faisons un peu de mathématiques

Nous espérons ne pas faire peur à personne ici, même si l'algèbre c'est vraiment loin dans les tiroirs de notre cerveau. C'est important et je peux vous aider!

Le coût total par kilomètre se calcule comme suit, où $K$ est le nombre de kilomètres :

$$
P(K) = K*C_0 + (4+0.5*K)*C_1 + (8+0,4*K)*C_2
$$

Nous cherchons les bonnes valeurs des paramètres $C_0,C_1,C_2$, qui représentent chacun le choix d'un des trois modes de transport

$$
C_0,C_1,C_2 \in \lbrace 0,1 \rbrace \\
C_0+C_1+C_2=1 \\
$$

Nous minimisons donc la fonction suivante :

$$
argmin_{(C_0,C_1,C_2)} (P(K))
$$

### À la recherche de solutions

À l'aide de la librairie [lpSolve](https://sourceforge.net/projects/lpsolve/) en R, nous pouvons définir un problème de coût minimum en quelques lignes et ensuite générer des scénarios.

Ce dernier s'exprime sous la forme d'une équation linéaire et, en calculant la solution pour toutes les distances de 1 à 50 kilomètres, nous apprenons que :

- Avec moins de 8 kilomètres à parcourir, il est préférable de pédaler.
- À partir de 40 kilomètres, il est recommandé de prendre la voiture au lieu du transport public.

![Graphique du coût par kilomètre](Images/cout_moyen_transport.png)
